##############################################################################
#
# Copyright (c) 2005 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""
$Id: tests.py 96943 2009-02-21 14:40:06Z icemac $
"""

import unittest
import z3c.layer
import zope.app.testing.functional


layer = zope.app.testing.functional.defineLayer('TestLayer', 'ftesting.zcml')


class ITrustedTestingSkin(z3c.layer.trusted.ITrustedBrowserLayer):
    """The ITrustedBrowserLayer testing skin."""


def test_suite():
    suite = unittest.TestSuite()
    s = zope.app.testing.functional.FunctionalDocFileSuite('README.txt')
    s.layer = TestLayer
    suite.addTest(s)

    return suite


if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')



#!python
##############################################################################
#
# Copyright (c) 2007 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Setup

$Id:$
"""
import os
from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

version = '1.1.0'

setup(
    name='z3c.layer.trusted',
    version=version,
    author='Zope Foundation and Contributors',
    author_email='zope-dev@zope.org',
    description = "Trusted layer setup for Zope3",
    long_description=(
        read('README.txt')
        + '\n\n' +
        '.. contents::\n'
        + '\n\n' +
        read('src', 'z3c', 'layer', 'trusted', 'README.txt')
        + '\n\n' +
        read('CHANGES.txt')
        ),
    keywords = "z3c trusted layer zope zope3",
    classifiers = [
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Zope Public License',
        'Programming Language :: Python',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
        'Framework :: Zope3'],
    url='http://pypi.python.org/pypi/z3c.layer.trusted',
    license='ZPL 2.1',
    packages = find_packages('src'),
    include_package_data = True,
    package_dir = {'':'src'},
    namespace_packages = ['z3c', 'z3c.layer'],
    extras_require = dict(
        test = [
            'zope.testbrowser',
            'zope.app.testing',
            'zope.app.zcmlfiles',
            'z3c.layer.minimal [test]',
            ],
        ),
    install_requires = [
        'setuptools',
        'zope.publisher',
        'zope.app.publication',
        'zope.container',
        'z3c.layer.minimal',
        ],
    zip_safe = False,
)

